@@ -4,12 +4,12 @@ class Command():
 
   def __init__(self, app: App):
     self.__app = app
-    self.__namespace = app.namespace
+    self.__scaffold_namespace = app.scaffold_namespace
 
   @property
   def app(self):
     return self.__app
 
   @property
-  def namespace(self):
-    return self.__namespace
\ No newline at end of file
+  def scaffold_namespace(self):
+    return self.__scaffold_namespace
\ No newline at end of file
