@@ -15,10 +15,10 @@ class TestOptions(TypedDict):
   lifecycle_hooks_path: str
   log_level: logger.LogLevel
   output_level: test_output_level.TestOutputLevel
-  public_directory_path: str
+  public_directory_path: str  # Comma-separated list of paths, optionally with origin suffix (e.g., "/path/to/files:example.com,/other/path")
   remote_project_key: str
   report_key: str
-  response_fixtures_path: str
+  response_fixtures_path: str  # Comma-separated list of paths, optionally with origin suffix (e.g., "/path/to/fixtures.yml:example.com,/other/fixtures.yml")
   save: str
   scheme: str
   strategy: test_strategy.TestStrategy
