@@ -5,6 +5,8 @@ import signal
 
 from mitmproxy.net import tls
 
+from stoobly_agent.app.cli.scaffold.constants import SERVICE_NAME_ENV
+from stoobly_agent.app.cli.scaffold.templates.constants import CORE_MOCK_UI_SERVICE_NAME
 from stoobly_agent.config.mitmproxy import MitmproxyConfig
 
 # Monkey patch for OpenSSL unsafe legacy renegotiation disabled
@@ -14,8 +16,6 @@ tls.DEFAULT_OPTIONS |= 0x4
 from mitmproxy.options import Options
 from mitmproxy.tools.dump import DumpMaster
 
-from stoobly_agent.app.settings import Settings
-
 INTERCEPT_HANDLER_FILENAME = 'intercept_handler.py'
 
 def run(**kwargs):
@@ -65,7 +65,6 @@ def __with_static_options(config: MitmproxyConfig, cli_options):
     config.set(options)
 
 def __with_cli_options(config: MitmproxyConfig, cli_options: dict):
-    __commit_options(cli_options)
     __filter_options(cli_options)
 
     options = []
@@ -84,23 +83,12 @@ def __with_cli_options(config: MitmproxyConfig, cli_options: dict):
 
     config.set(tuple(options))
 
-def __commit_options(options: dict):
-    settings = Settings.instance()
-
-    settings.proxy.intercept.active = not not options.get('intercept')
-
-    if options.get('proxy_host') and options.get('proxy_port'):
-        settings.proxy.url = f"http://{options.get('proxy_host')}:{options.get('proxy_port')}"
-
-    settings.ui.active = not options.get('headless')
-
-    settings.commit()
-
 def __filter_options(options):
     ''' 
     Filter out non-mitmproxy options
     '''
 
+    options['confdir'] = options['ca_certs_dir_path']
     options['listen_host'] = options['proxy_host']
     options['listen_port'] = options['proxy_port']
     options['mode'] = options['proxy_mode']
@@ -108,18 +96,27 @@ def __filter_options(options):
     if 'api_url' in options:
         del options['api_url']
 
+    if 'ca_certs_dir_path' in options:
+        del options['ca_certs_dir_path']
+
     if 'certs' in options and not options['certs']:
         del options['certs']
 
     if 'cert_passphrase' in options and not options['cert_passphrase']:
         del options['cert_passphrase']
 
+    if 'detached' in options:
+        del options['detached']
+
     if 'headless' in options:
         del options['headless']
 
     if 'intercept' in options:
         del options['intercept']
 
+    if 'intercept_mode' in options:
+        del options['intercept_mode']
+
     if 'lifecycle_hooks_path' in options:
         del options['lifecycle_hooks_path']
 
