@@ -1,8 +1,10 @@
 AFTER_MOCK = 'handle_after_mock'
+AFTER_MOCK_NOT_FOUND = 'handle_after_mock_not_found'
 AFTER_RECORD = 'handle_after_record'
 AFTER_REPLAY = 'handle_after_replay'
 AFTER_TEST = 'handle_after_test'
 BEFORE_MOCK = 'handle_before_mock'
+BEFORE_MIGRATE = 'handle_before_migrate'
 BEFORE_RECORD = 'handle_before_record'
 BEFORE_REPLAY = 'handle_before_replay'
 BEFORE_REQUEST = 'handle_before_request'
